@@ -1,12 +1,36 @@
-package EAI::DateUtil 0.7;
+package EAI::DateUtil 0.8;
 
-use strict; use warnings;
+use strict; use warnings; use feature 'unicode_strings'; use utf8;
 use Exporter qw(import); use Time::Local qw( timelocal_modern timegm_modern ); use Time::localtime; use POSIX qw(mktime); use Data::Dumper;
 
-our @EXPORT = qw(%months %monate get_curdate get_curdatetime get_curdate_dot formatDate formatDateFromYYYYMMDD get_curdate_dash get_curdate_gen get_curdate_dash_plus_X_years get_curtime get_curtime_HHMM get_lastdateYYYYMMDD get_lastdateDDMMYYYY is_first_day_of_month is_last_day_of_month get_last_day_of_month weekday is_weekend is_holiday first_week first_weekYYYYMMDD last_week last_weekYYYYMMDD convertDate convertDateFromMMM convertDateToMMM convertToDDMMYYYY addDays addDaysHol addDatePart subtractDays subtractDaysHol convertcomma convertToThousendDecimal get_dateseries parseFromDDMMYYYY parseFromYYYYMMDD convertEpochToYYYYMMDD is_easter addCalendar);
+our @EXPORT = qw(monthsToInt intToMonths addLocaleMonths get_curdate get_curdatetime get_curdate_dot formatDate formatDateFromYYYYMMDD get_curdate_dash get_curdate_gen get_curdate_dash_plus_X_years get_curtime get_curtime_HHMM get_lastdateYYYYMMDD get_lastdateDDMMYYYY is_first_day_of_month is_last_day_of_month get_last_day_of_month weekday is_weekend is_holiday is_easter addCalendar first_week first_weekYYYYMMDD last_week last_weekYYYYMMDD convertDate convertDateFromMMM convertDateToMMM convertToDDMMYYYY addDays addDaysHol addDatePart subtractDays subtractDaysHol convertcomma convertToThousendDecimal get_dateseries parseFromDDMMYYYY parseFromYYYYMMDD convertEpochToYYYYMMDD);
 
-our %months = ("Jan" => "01","Feb" => "02","Mar" => "03","Apr" => "04","May" => "05","Jun" => "06","Jul" => "07","Aug" => "08","Sep" => "09","Oct" => "10","Nov" => "11","Dec" => "12");
-our %monate = ("Jan" => "01","Feb" => "02","Mär" => "03","Apr" => "04","Mai" => "05","Jun" => "06","Jul" => "07","Aug" => "08","Sep" => "09","Okt" => "10","Nov" => "11","Dez" => "12");
+my %monthsToInt = (
+	"en" => {"jan" => "01","feb" => "02","mar" => "03","apr" => "04","may" => "05","jun" => "06","jul" => "07","aug" => "08","sep" => "09","oct" => "10","nov" => "11","dec" => "12"},
+	"ge" => {"jan" => "01","feb" => "02","mär" => "03","apr" => "04","mai" => "05","jun" => "06","jul" => "07","aug" => "08","sep" => "09","okt" => "10","nov" => "11","dez" => "12"}
+);
+my %intTomonths = (
+	"en" => ["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],
+	"ge" => ["Jan","Feb","Mär","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Dez"]
+);
+
+sub monthsToInt ($$) {
+	my ($m,$locale) = @_;
+	if ($intTomonths{lc($locale)} and defined($monthsToInt{lc($locale)}{$m})) {
+		return $monthsToInt{lc($locale)}{$m};
+	} else {
+		return "";
+	}
+}
+
+sub intToMonths ($$) {
+	my ($m,$locale) = @_;
+	if ($intTomonths{lc($locale)} and @{$intTomonths{lc($locale)}} >= $m) {
+		return $intTomonths{lc($locale)}[$m-1];
+	} else {
+		return "";
+	}
+}
 
 sub get_curdate {
 	return sprintf("%04d%02d%02d",localtime->year()+ 1900, localtime->mon()+1, localtime->mday());
@@ -20,19 +44,39 @@ sub get_curdate_dot {
 	return sprintf("%02d.%02d.%04d",localtime->mday(), localtime->mon()+1, localtime->year()+ 1900);
 }
 
+sub addLocaleMonths ($$) {
+	my ($locale,$monthList) = @_;
+	$locale = lc($locale);
+	if (defined($monthsToInt{$locale})) {
+		warn("locale <$locale> already implemented for monthsToInt !");
+		return 0;
+	}
+	if (defined($intTomonths{$locale})) {
+		warn("locale <$locale> already implemented for intTomonths !");
+		return 0;
+	}
+	$intTomonths{$locale} = $monthList;
+	my $i = 1;
+	for (@$monthList) {
+		$monthsToInt{$locale}{lc($_)} = sprintf("%02d", $i);
+		$i++;
+	}
+	return 1;
+}
+
 sub formatDate ($$$;$) {
 	my ($y,$m,$d,$template) = @_;
 	$template = "YMD" if !$template;
-	my @months = ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');
-	my @monate = ('Jän', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez');
+	my ($locale) = $template =~ /\[(.*?)\]$/;
 	my $result = $template;
+	$result =~ s/\[$locale\]// if $locale;
 	$y = sprintf("%04d", $y);
 	$m = sprintf("%02d", $m);
 	$d = sprintf("%02d", $d);
 	if ($result =~ /MMM/i) {
-		my $mmm;
-		$mmm = $months[$m-1] if $result =~ /MMM/;
-		$mmm = $monate[$m-1] if $result =~ /mmm/;
+		$locale = "ge" if $result =~ /mmm/ and !$locale;
+		$locale = "en" if !$locale;
+		my $mmm = intToMonths($m,$locale);
 		$result =~ s/MMM/$mmm/i;
 	} else {
 		$result =~ s/M/$m/;
@@ -424,19 +468,21 @@ sub convertEpochToYYYYMMDD ($) {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 EAI::DateUtil - Date and Time helper functions for L<EAI::Wrap>
 
 =head1 SYNOPSIS
 
- %months = ("Jan" => "01","Feb" => "02","Mar" => "03","Apr" => "04","May" => "05","Jun" => "06","Jul" => "07","Aug" => "08","Sep" => "09","Oct" => "10","Nov" => "11","Dec" => "12");
- %monate = ("Jan" => "01","Feb" => "02","Mär" => "03","Apr" => "04","Mai" => "05","Jun" => "06","Jul" => "07","Aug" => "08","Sep" => "09","Okt" => "10","Nov" => "11","Dez" => "12");
-
+ monthsToInt ($mmm, $locale)
+ intToMonths ($m, $locale)
+ addLocaleMonths ($locale, $monthsArray)
  get_curdate ()
  get_curdatetime ()
  get_curdate_dot ()
- formatDate ($d, $m, $y, [$template])
+ formatDate ($y, $m, $d, [$template])
  formatDateFromYYYYMMDD($date, [$template])
  get_curdate_gen ([$template])
  get_curdate_dash ()
@@ -451,6 +497,8 @@ EAI::DateUtil - Date and Time helper functions for L<EAI::Wrap>
  weekday ($date YYYYMMDD)
  is_weekend ($date YYYYMMDD)
  is_holiday ($cal, $date YYYYMMDD)
+ is_easter ($cal, $date YYYYMMDD)
+ addCalendar ($cal, $fixedHol hash, $easterHol .. hash, $specialFunction)
  first_week ($d,$m,$y,$day,[$month])
  first_weekYYYYMMDD ($date,$day,[$month])
  last_week ($d,$m,$y,$day,[$month])
@@ -479,13 +527,21 @@ EAI::DateUtil contains all date/time related API-calls.
 
 =over
 
-=item %months
+=item monthsToInt
 
-conversion hash english months -> numbers, usage: $months{"Oct"} equals 10
+convert from english/german/custom locale short months -> numbers, monthsToInt("Oct","EN") equals 10, monthsToInt("mär","GE") equals 3. months and locale are case insensitive.
 
-=item %monate
+=item intToMonths
 
-conversion hash german months -> numbers, usage: $monate{"Okt"} equals 10
+convert from int to english/german/custom locale months -> numbers, intToMonths(10,"EN") equals "Oct", intToMonths(3,"GE") equals "Mär". locale is case insensitive, month is returned with uppercase beginnen resp. as it was added (see below).
+
+=item addLocaleMonths
+
+adds custom locale $locale with ref to array $monthsArray to above conversion functions. locale is case insensitive.
+
+Example:
+
+ addLocaleMonths("FR",["Jan","Fév","Mars","Mai","Juin","Juil","Août","Sept","Oct","Nov","Déc"]);
 
 =item get_curdate
 
@@ -503,12 +559,14 @@ gets current date in format DD.MM.YYYY
 
 formats passed date (given in arguments $y,$m,$d) into format as defined in $template
 
- $d .. day part
- $m .. month part
  $y .. year part
+ $m .. month part
+ $d .. day part
  $template .. optional, date template with D for day, M for month and Y for year (e.g. D.M.Y for 01.02.2016),
               D and M is always 2 digit, Y always 4 digit; if empty/nonexistent defaults to "YMD"
               special formats are MMM und mmm als monthpart, here three letter month abbreviations in english (MMM) or german (mmm) are returned as month
+              additionally a locale can be passed in brackets with MMM and mmm, resulting in conversion to locale dependent months.
+              e.g. formatDate(2002,6,1,"Y-MMM-D[fr]") would yield 2002-Juin-01 for the addLocaleMonths given above.
 
 =item formatDateFromYYYYMMDD
 
@@ -582,14 +640,14 @@ returns 1 if weekend or holiday
          throws warning if calendar not supported (fixed lookups or additionally added). To add a calendar use addCalendar.
  $date .. date in format YYYYMMDD
 
-= is_easter
+=item is_easter
 
 returns 1 if date is an easter holiday for that calendar
 
  $cal .. holiday calendar;
  $date .. date in format YYYYMMDD
 
-= addCalendar
+=item addCalendar
 
 add an additional calendar for calendar holiday dependent calculations
 
@@ -599,12 +657,13 @@ add an additional calendar for calendar holiday dependent calculations
  $specialFunction .. pass ref to sub used for additional calculations; this sub should receive a date (YYYYMMDD) and return 1 for holiday, 0 otherwise.
 
 Example:
-sub testCalSpecial {
-	my ($y,$m,$d) = $_[0] =~ /(.{4})(..)(..)/;
-	return 1 if $y eq "2002" and $m eq "09" and $d eq "08";
-	return 0;
-}
-addCalendar("TC",{"0101"=>1,"0105"=>1,"2512"=>1,"2612"=>1},{"EM"=>1,"GF"=>1},\&testCalSpecial)
+
+ sub testCalSpecial {
+   my ($y,$m,$d) = $_[0] =~ /(.{4})(..)(..)/;
+   return 1 if $y eq "2002" and $m eq "09" and $d eq "08";
+   return 0;
+ }
+ addCalendar("TC",{"0101"=>1,"0105"=>1,"2512"=>1,"2612"=>1},{"EM"=>1,"GF"=>1},\&testCalSpecial);
 
 =item last_week
 
